@@ -12,14 +12,19 @@ def add_two_numbers(a: int, b: int) -> int:
   Returns:
     int: The sum of the two numbers
   """
-  return a + b
+
+  # The cast is necessary as returned tool call arguments don't always conform exactly to schema
+  # E.g. this would prevent "what is 30 + 12" to produce '3012' instead of 42
+  return int(a) + int(b)
 
 
 def subtract_two_numbers(a: int, b: int) -> int:
   """
   Subtract two numbers
   """
-  return a - b
+
+  # The cast is necessary as returned tool call arguments don't always conform exactly to schema
+  return int(a) - int(b)
 
 
 # Tools can still be manually defined and passed into chat
