@@ -1,40 +1,40 @@
-from ollama._client import Client, AsyncClient
+from ollama._client import AsyncClient, Client
 from ollama._types import (
-  Options,
-  Message,
-  Image,
-  Tool,
-  GenerateResponse,
   ChatResponse,
-  EmbedResponse,
   EmbeddingsResponse,
-  StatusResponse,
-  ProgressResponse,
+  EmbedResponse,
+  GenerateResponse,
+  Image,
   ListResponse,
-  ShowResponse,
+  Message,
+  Options,
   ProcessResponse,
+  ProgressResponse,
   RequestError,
   ResponseError,
+  ShowResponse,
+  StatusResponse,
+  Tool,
 )
 
 __all__ = [
-  'Client',
   'AsyncClient',
-  'Options',
-  'Message',
-  'Image',
-  'Tool',
-  'GenerateResponse',
   'ChatResponse',
+  'Client',
   'EmbedResponse',
   'EmbeddingsResponse',
-  'StatusResponse',
-  'ProgressResponse',
+  'GenerateResponse',
+  'Image',
   'ListResponse',
-  'ShowResponse',
+  'Message',
+  'Options',
   'ProcessResponse',
+  'ProgressResponse',
   'RequestError',
   'ResponseError',
+  'ShowResponse',
+  'StatusResponse',
+  'Tool',
 ]
 
 _client = Client()
